<?php
namespace Claromentis\Mailgun\Model;

$GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"] ?: array()) + array("_618a4aeb9fecc4592a45" . "21f34876fa29" => base64_decode("ZnJvbQ=" . "="), "_6e1c717" . "cf3cbf1a" . "f982ed74" . "d4336b7f" . "1" => base64_decode("Ym9ke" . "S1odG" . "1s"), "_f589476" . "007fa133" . "f457c3ef" . "29ddfa56" . "6" => base64_decode("V" . "G" . "8" . "="), "_a1e707d02a236da" . "debd15a45e65ebdb" . "6" => base64_decode("YXR0YWNobWVudC1jb3Vud" . "A=="), "_f39f5346e3" . "13e4dd1ac3a" . "7bd8032beda" => base64_decode("c3Vic3RyX2Nvb" . "XBhcmU="), "_44e986c04f41a08b56a383c7b3a8" . "8ee2" => base64_decode("c2VuZ" . "GVy"), "_d706c160e45bf7434fff8" . "2a5976f0e19" => base64_decode("YXJyYX" . "lfa2V5" . "cw=="), "_956cd32298a229f9768f1096f07" . "7ace3" => base64_decode("Ym9keS" . "1wbGFp" . "bg=="), "_97ea09a7faf27c52c6eff69773df1" . "d8a" => base64_decode("dGltZX" . "N0YW1w"), "_1d6c68a0262e8fa0bed1215b7224a" . "98e" => base64_decode("cmV" . "jaX" . "BpZ" . "W50"), "_9c050c786fc" . "87170cbb84fc" . "6a8b13cb6" => base64_decode("YXR0YWN" . "obWVudC" . "0="), "_8c57591" . "7cbaedf1" . "e7efae84" . "939402bf" . "f" => base64_decode("U3ViamVjdA" . "=="));
use Claromentis\Core\Mail\Receive\Contract\MailAttachment;
use Claromentis\Core\Mail\Receive\Contract\MailMessage;
use Claromentis\Core\Util\ArrayUtil;




class MailgunMessage implements MailMessage
{
    protected $message_data;
    protected $attachments_data;
    protected $attachments;
    
    
    
    
    
    public function __construct($_a3d82c5df38e194c9c73e3ccb4223bbc = [], $_4e7ab34a53ffb13eb0838003f33034d4 = [])
    {
        $this->message_data = $_a3d82c5df38e194c9c73e3ccb4223bbc;
        $this->attachments = $_4e7ab34a53ffb13eb0838003f33034d4;
        foreach ($GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"]["_d706c160" . "e45bf7434" . "fff82a597" . "6f0e19"]($this->message_data) as $key) {
            if ($key !== $GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"]["_a1e707d02a236dad" . "ebd15a45e65ebdb6"] && $GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"]["_f39f5346e313e4dd1ac3a" . "7bd8032beda"]($key, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"]["_9c050c786fc871" . "70cbb84fc6a8b13" . "cb6"], 0, 11) === 0) {
                $this->attachments[] = new MailgunAttachmentString($key, $this->message_data[$key]);
            }
        }
    }
    
    
    
    
    public function GetRecipientAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_1d6c68a" . "0262e8fa" . "0bed1215" . "b7224a98" . "e"]);
    }
    
    
    
    
    
    
    public function GetFrom() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"]["_618a4aeb9fecc4592a4" . "521f34876fa29"]], null);
    }
    
    
    
    
    
    
    
    public function GetTo() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_f589476007fa133f457c3ef29" . "ddfa566"]], null);
    }
    
    
    
    
    public function GetSubject() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_8c575917c" . "baedf1e7ef" . "ae84939402" . "bff"]);
    }
    
    
    
    
    public function GetBodyHtml() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"]["_6e1c717cf3cbf" . "1af982ed74d433" . "6b7f1"]);
    }
    
    
    
    
    public function GetBodyText() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"]["_956cd322" . "98a229f97" . "68f1096f0" . "77ace3"]);
    }
    
    
    
    
    public function GetDate() : \Date
    {
        $_67a0d624aebcceb0abd5ce56a53ff06f = new \Date(ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"]["_97ea09a7fa" . "f27c52c6eff" . "69773df1d8a"]));
        return $_67a0d624aebcceb0abd5ce56a53ff06f;
    }
    
    
    
    
    public function GetSenderAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"]["_44e986c04f41a08b56a3" . "83c7b3a88ee2"]);
    }
    public function GetAttachments()
    {
        return $this->attachments;
    }
}